macro_rules! tri {
($expr: expr) => { ... };
}Expand description
Unwraps a result or propagates its error as an exception.
tri! matches the given Result. In case of the Ok variant, the expression has the value of the wrapped value. In case of the Err variant, it retrieves the inner error, and calls throw on it.